package cc.smtweb.system.bpm.web.sys.user.menu;

import cc.smtweb.framework.core.common.SwEnum;
import cc.smtweb.framework.core.common.SwMap;
import cc.smtweb.framework.core.db.impl.DefaultEntity;
import cc.smtweb.framework.core.util.JsonUtil;
import cc.smtweb.framework.core.util.PubUtil;
import cc.smtweb.system.bpm.web.design.form.define.PageDataset;
import cc.smtweb.system.bpm.web.engine.dynPage.DynPageListHandler;
import cc.smtweb.system.bpm.web.engine.dynPage.DynPageLoadHandler;
import cc.smtweb.system.bpm.web.engine.dynPage.DynPageSaveHandler;
import cc.smtweb.system.bpm.web.engine.dynPage.DynPageTreeHandler;

import java.util.List;
import java.util.Map;

/**
 * @Author: tanghp
 * @Date: 2022-08-01 17:47
 * @Desc:
 */
public class MenuHandler {
    static class MenuLoadHandler extends DynPageLoadHandler {
        @Override
        public DynPageTreeHandler getTreeWorker(SwMap filter, PageDataset pageDataSet) {
            DynPageTreeHandler treeHandler = new MenuTreeHandler(pageId, filter, pageDataSet);
            treeHandler.init(params, us);
            return treeHandler;
        }

        @Override
        public DynPageListHandler getListWorker(SwMap filter, PageDataset pageDataSet) {
            DynPageListHandler listHandler = new MenuListHandler(pageId, filter, pageDataSet);
            listHandler.init(params, us);
            return listHandler;
        }

        @Override
        protected void afterLoadBean(PageDataset dataset, SwMap bean) {
            super.afterLoadBean(dataset, bean);
            Menu menu = new Menu();
            menu.setData(bean);
            if (PubUtil.isNotEmptyStr(menu.getContent())) {
                Map<String, String> urlMap = JsonUtil.parseMap(menu.getContent());
                bean.put("sm_page_id", urlMap.get("pageId"));
                bean.put("sm_page_url", urlMap.get("path"));
            }
            if (PubUtil.isNotEmptyStr(menu.getRight())) {
                Map<String, List<String>> rightMap = JsonUtil.parseMap(menu.getRight());
                bean.put("sm_right_data", PubUtil.getSqlInIds(rightMap.get("data")));
                bean.put("sm_right_func", PubUtil.getSqlInIds(rightMap.get("func")));
                bean.put("sm_right_field", PubUtil.getSqlInIds(rightMap.get("field")));
            }
        }
    }

    static class MenuSaveHandler extends DynPageSaveHandler {

        @Override
        protected DefaultEntity readBeanFromPage(PageDataset pageDataSet, SwMap data) {
            if (pageDataSet.isCurTable(Menu.ENTITY_NAME)) {
                //处理请求内容
                SwMap sm_content = new SwMap();
                sm_content.put("pageId", data.readString("sm_page_id"));
                sm_content.put("path", data.readString("sm_page_url"));
                data.put("sm_content", JsonUtil.encodeString(sm_content));
                //处理权限点
                SwMap sm_right = new SwMap();
                sm_right.put("data", data.readStringList("sm_right_data"));
                sm_right.put("func", data.readStringList("sm_right_func"));
                sm_right.put("field", data.readStringList("sm_right_field"));
                data.put("sm_right", JsonUtil.encodeString(sm_right));
                return super.readBeanFromPage(pageDataSet, data);
            }
            return super.readBeanFromPage(pageDataSet, data);
        }
    }

    static class MenuTreeHandler extends DynPageTreeHandler {

        public MenuTreeHandler(long pageId, SwMap filter, PageDataset pageDataSet) {
            super(pageId, filter, pageDataSet);
        }
    }

    static class MenuListHandler extends DynPageListHandler {

        public MenuListHandler(long pageId, SwMap filter, PageDataset pageDataSet) {
            super(pageId, filter, pageDataSet);
        }

        @Override
        protected void afterQuery(List<SwMap> listData) {
            super.afterQuery(listData);
            listData.forEach(row -> {
                row.put("sm_type_text", SwEnum.MenuType.instance.getName(row.readInt("sm_type")));
            });
        }
    }
}
